.. motion documentation master file, created by
   sphinx-quickstart on Thu Jun  4 14:44:05 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

``motion`` – Motion in the TypePad cloud
========================================

``motion`` is a Django application that provides the Motion experience using
accounts and storage in the TypePad cloud.

Contents:

.. toctree::
   :maxdepth: 2

   settings
   views
   featured
   themes
   wsgi

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

